{ pkgs, lib, ... }:

{
  imports = [
    # Modules
    ../../modules/home/default.nix
  ];

  config = {
    home = {
      username = "xeovalyte";
      homeDirectory = "/home/xeovalyte";
    };

    settings = {
      applications.common.enable = true;
      applications.alacritty.enable = false;
      applications.devenv.enable = true;
      applications.firefox.enable = true;
      applications.git.enable = true;
      applications.helix = {
        enable = true;
        markdown = true;
        rust = true;
        systemverilog = true;
        nix = true;
        latex = true;
        vue = true;
      };
      applications.zsh.enable = true;
      applications.ssh.enable = true;
      applications.thunderbird.enable = true;
      applications.yazi.enable = true;
      applications.zellij.enable = true;
      applications.wezterm.enable = true;
      applications.typst.enable = true;

      services.nextcloud-sync.enable = true;

      theming.fonts.enable = true;
      theming.stylix.enable = true;
      theming.stylix.wallpaper = "wallpaper-2.png";
      theming.stylix.theme = "da-one-ocean";

      desktop-environments.hyprland.enable = false;
    };

    home.packages = with pkgs; [
      unstable.prismlauncher
      unstable.vesktop
      unstable.webcord
      unstable.legcord
      unstable.rnote
      unstable.inkscape
      unstable.gimp
      unstable.openscad-unstable
      unstable.brave
      unstable.freecad
      unstable.hoppscotch
      unstable.signal-desktop
      unstable.ladybird
      unstable.prusa-slicer

      unstable.surfer # waveform viewer
      pomodoro-gtk

      # Office
      libreoffice

      # Scripts
      (import ../../modules/scripts/save_image.nix { inherit pkgs; })
    ];

    # Enable home-manager
    programs.home-manager.enable = true;

    home.stateVersion = "24.05";
  };
}
